async fn current_gateway_latency(ctx: &Context) -> Option<Duration>Expand description
Reads the gateway heartbeat latency for the shard handling this context.
None if the shard manager isn’t registered in ctx.data, or if no
heartbeat acknowledgement has been received yet for this shard.